types

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2024 License: MIT Imports: 0 Imported by: 3

Documentation

Index

Constants

const RABBTIMQ_EXCHANGE = "exchange"

Variables

This section is empty.

Functions

This section is empty.

Types

type Event

type Event interface {
	GetEventType() EventType
	GetEventData() map[string]interface{}
}

Events are sent to the even handler system, to be published to all subscribers. Events are written on basis on what is to be sent, they require a method that defines the eventType and the data to be sent.

The data must conform to json (map[string]interface{})

type EventHandlerImplementationType

type EventHandlerImplementationType string
const RABBITMQ_3_12_12_EVENT_HANDLER EventHandlerImplementationType = "rabbitmq-3.12.12"

type EventType

type EventType string

Jump to